



pip check
IF %ERRORLEVEL% NEQ 0 exit /B 1
python -c "__import__('en_core_web_md').load()"
IF %ERRORLEVEL% NEQ 0 exit /B 1
python -c "__import__('spacy').load('en_core_web_md')"
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
